rpc_lesson1 Example
===================

Python Version
--------------

Model Code:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/server.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/client.py
   :language: python
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/server_python.yml
   :language: yaml
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/client_python.yml
   :language: yaml
   :linenos:



C++ Version
-----------

Model Code:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/server.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/client.cpp
   :language: c++
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/server_python.yml
   :language: yaml
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/client_cpp.yml
   :language: yaml
   :linenos:



C Version
---------

Model Code:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/server.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/client.c
   :language: c
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/server_python.yml
   :language: yaml
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/client_c.yml
   :language: yaml
   :linenos:



Matlab Version
--------------

Model Code:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/server.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/src/client.m
   :language: matlab
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/server_python.yml
   :language: yaml
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson1/client_matlab.yml
   :language: yaml
   :linenos:



